Tutorials
=========

This section contains some practical examples of setting up and using Terracotta.
These tutorials are intended to help you get started with Terracotta; they are not meant
as authoritive references or strict demonstrations of best practices.

If you run into problems following any of the tutorials, please let us know by 
`opening an issue <https://github.com/DHI-GRAS/terracotta/issues>`__.

.. toctree::
   :maxdepth: 1
   :caption: Available tutorials:

   tutorials/aws
   tutorials/wsgi
   tutorials/categorical
   tutorials/windows
